==> play-slick_3-6.0.0-M1-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html#","e":false,"i":"","n":"play-slick","t":"play-slick","d":"","k":"static","x":""},
{"l":"play/api/db/slick.html#","e":false,"i":"","n":"play.api.db.slick","t":"play.api.db.slick","d":"","k":"package","x":""},
{"l":"play/api/db/slick/DatabaseConfigProvider.html#","e":false,"i":"","n":"DatabaseConfigProvider","t":"DatabaseConfigProvider","d":"play.api.db.slick","k":"trait","x":""},
{"l":"play/api/db/slick/DatabaseConfigProvider.html#get-a04","e":false,"i":"","n":"get","t":"get[P <: BasicProfile]: DatabaseConfig[P]","d":"play.api.db.slick.DatabaseConfigProvider","k":"def","x":""},
{"l":"play/api/db/slick/DatabaseConfigProvider$.html#","e":false,"i":"","n":"DatabaseConfigProvider","t":"DatabaseConfigProvider","d":"play.api.db.slick","k":"object","x":""},
{"l":"play/api/db/slick/DatabaseConfigProvider$.html#get-9a6","e":false,"i":"","n":"get","t":"get[P <: BasicProfile](implicit app: Application): DatabaseConfig[P]","d":"play.api.db.slick.DatabaseConfigProvider","k":"def","x":""},
{"l":"play/api/db/slick/DatabaseConfigProvider$.html#get-fffff54b","e":false,"i":"","n":"get","t":"get[P <: BasicProfile](dbName: String)(implicit app: Application): DatabaseConfig[P]","d":"play.api.db.slick.DatabaseConfigProvider","k":"def","x":""},
{"l":"play/api/db/slick/DbName.html#","e":false,"i":"","n":"DbName","t":"DbName(value: String) extends AnyVal","d":"play.api.db.slick","k":"class","x":""},
{"l":"play/api/db/slick/DefaultSlickApi.html#","e":false,"i":"","n":"DefaultSlickApi","t":"DefaultSlickApi(environment: Environment, configuration: Configuration, lifecycle: ApplicationLifecycle)(implicit executionContext: ExecutionContext) extends SlickApi","d":"play.api.db.slick","k":"class","x":""},
{"l":"play/api/db/slick/DefaultSlickApi.html#dbConfig-fffffa29","e":false,"i":"","n":"dbConfig","t":"dbConfig[P <: BasicProfile](name: DbName): DatabaseConfig[P]","d":"play.api.db.slick.DefaultSlickApi","k":"def","x":""},
{"l":"play/api/db/slick/DefaultSlickApi.html#dbConfigs-fffffe9c","e":false,"i":"","n":"dbConfigs","t":"dbConfigs[P <: BasicProfile](): Seq[(DbName, DatabaseConfig[P])]","d":"play.api.db.slick.DefaultSlickApi","k":"def","x":""},
{"l":"play/api/db/slick/DefaultSlickApi$.html#","e":false,"i":"","n":"DefaultSlickApi","t":"DefaultSlickApi","d":"play.api.db.slick","k":"object","x":""},
{"l":"play/api/db/slick/HasDatabaseConfig.html#","e":false,"i":"","n":"HasDatabaseConfig","t":"HasDatabaseConfig[P <: BasicProfile]","d":"play.api.db.slick","k":"trait","x":""},
{"l":"play/api/db/slick/HasDatabaseConfig.html#db-0","e":false,"i":"","n":"db","t":"db: Database","d":"play.api.db.slick.HasDatabaseConfig","k":"def","x":""},
{"l":"play/api/db/slick/HasDatabaseConfig.html#dbConfig-0","e":false,"i":"","n":"dbConfig","t":"dbConfig: DatabaseConfig[P]","d":"play.api.db.slick.HasDatabaseConfig","k":"val","x":""},
{"l":"play/api/db/slick/HasDatabaseConfig.html#driver-0","e":false,"i":"","n":"driver","t":"driver: P","d":"play.api.db.slick.HasDatabaseConfig","k":"val","x":""},
{"l":"play/api/db/slick/HasDatabaseConfig.html#profile-0","e":false,"i":"","n":"profile","t":"profile: P","d":"play.api.db.slick.HasDatabaseConfig","k":"val","x":""},
{"l":"play/api/db/slick/HasDatabaseConfigProvider.html#","e":false,"i":"","n":"HasDatabaseConfigProvider","t":"HasDatabaseConfigProvider[P <: BasicProfile] extends HasDatabaseConfig[P]","d":"play.api.db.slick","k":"trait","x":""},
{"l":"play/api/db/slick/HasDatabaseConfigProvider.html#dbConfig-0","e":false,"i":"","n":"dbConfig","t":"dbConfig: DatabaseConfig[P]","d":"play.api.db.slick.HasDatabaseConfigProvider","k":"val","x":""},
{"l":"play/api/db/slick/HasDatabaseConfigProvider.html#dbConfigProvider-0","e":false,"i":"","n":"dbConfigProvider","t":"dbConfigProvider: DatabaseConfigProvider","d":"play.api.db.slick.HasDatabaseConfigProvider","k":"val","x":""},
{"l":"play/api/db/slick/NamedDatabaseConfigProvider.html#","e":false,"i":"","n":"NamedDatabaseConfigProvider","t":"NamedDatabaseConfigProvider(name: String) extends Provider[DatabaseConfigProvider]","d":"play.api.db.slick","k":"class","x":""},
{"l":"play/api/db/slick/NamedDatabaseConfigProvider.html#get-0","e":false,"i":"","n":"get","t":"get: DatabaseConfigProvider","d":"play.api.db.slick.NamedDatabaseConfigProvider","k":"val","x":""},
{"l":"play/api/db/slick/SlickApi.html#","e":false,"i":"","n":"SlickApi","t":"SlickApi","d":"play.api.db.slick","k":"trait","x":""},
{"l":"play/api/db/slick/SlickApi.html#dbConfig-fffffa29","e":false,"i":"","n":"dbConfig","t":"dbConfig[P <: BasicProfile](name: DbName): DatabaseConfig[P]","d":"play.api.db.slick.SlickApi","k":"def","x":""},
{"l":"play/api/db/slick/SlickApi.html#dbConfigs-fffffe9c","e":false,"i":"","n":"dbConfigs","t":"dbConfigs[P <: BasicProfile](): Seq[(DbName, DatabaseConfig[P])]","d":"play.api.db.slick.SlickApi","k":"def","x":""},
{"l":"play/api/db/slick/SlickComponents.html#","e":false,"i":"","n":"SlickComponents","t":"SlickComponents","d":"play.api.db.slick","k":"trait","x":""},
{"l":"play/api/db/slick/SlickComponents.html#applicationLifecycle-0","e":false,"i":"","n":"applicationLifecycle","t":"applicationLifecycle: ApplicationLifecycle","d":"play.api.db.slick.SlickComponents","k":"def","x":""},
{"l":"play/api/db/slick/SlickComponents.html#configuration-0","e":false,"i":"","n":"configuration","t":"configuration: Configuration","d":"play.api.db.slick.SlickComponents","k":"def","x":""},
{"l":"play/api/db/slick/SlickComponents.html#environment-0","e":false,"i":"","n":"environment","t":"environment: Environment","d":"play.api.db.slick.SlickComponents","k":"def","x":""},
{"l":"play/api/db/slick/SlickComponents.html#executionContext-0","e":false,"i":"","n":"executionContext","t":"executionContext: ExecutionContext","d":"play.api.db.slick.SlickComponents","k":"def","x":""},
{"l":"play/api/db/slick/SlickComponents.html#slickApi-0","e":false,"i":"","n":"slickApi","t":"slickApi: SlickApi","d":"play.api.db.slick.SlickComponents","k":"val","x":""},
{"l":"play/api/db/slick/SlickModule$.html#","e":false,"i":"","n":"SlickModule","t":"SlickModule","d":"play.api.db.slick","k":"object","x":""},
{"l":"play/api/db/slick/SlickModule$.html#DbKeyConfig-0","e":false,"i":"","n":"DbKeyConfig","t":"DbKeyConfig: \"play.slick.db.config\"","d":"play.api.db.slick.SlickModule","k":"val","x":""},
{"l":"play/api/db/slick/SlickModule$.html#DefaultDbName-0","e":false,"i":"","n":"DefaultDbName","t":"DefaultDbName: \"play.slick.db.default\"","d":"play.api.db.slick.SlickModule","k":"val","x":""},
{"l":"play/api/db/slick/SlickModule.html#","e":false,"i":"","n":"SlickModule","t":"SlickModule extends Module","d":"play.api.db.slick","k":"class","x":""},
{"l":"play/api/db/slick/SlickModule.html#bindNamed-a4e","e":false,"i":"","n":"bindNamed","t":"bindNamed(name: String): BindingKey[DatabaseConfigProvider]","d":"play.api.db.slick.SlickModule","k":"def","x":""},
{"l":"play/api/db/slick/SlickModule.html#bindings-4d8","e":false,"i":"","n":"bindings","t":"bindings(environment: Environment, configuration: Configuration): Seq[Binding[_]]","d":"play.api.db.slick.SlickModule","k":"def","x":""},
{"l":"play/api/db/slick/SlickModule.html#defaultDatabaseConfigBinding-8be","e":false,"i":"","n":"defaultDatabaseConfigBinding","t":"defaultDatabaseConfigBinding(default: String, dbs: Set[String]): Seq[Binding[_]]","d":"play.api.db.slick.SlickModule","k":"def","x":""},
{"l":"play/api/db/slick/SlickModule.html#namedDatabaseConfigBindings-fd9","e":false,"i":"","n":"namedDatabaseConfigBindings","t":"namedDatabaseConfigBindings(dbs: Set[String]): Seq[Binding[_]]","d":"play.api.db.slick.SlickModule","k":"def","x":""}];

==> play-slick_3-7.0.0-M1-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html#","e":false,"i":"","n":"play-slick","t":"play-slick","d":"","k":"static","x":""},
{"l":"play/api/db/slick.html#","e":false,"i":"","n":"play.api.db.slick","t":"play.api.db.slick","d":"","k":"package","x":""},
{"l":"play/api/db/slick/DatabaseConfigProvider.html#","e":false,"i":"","n":"DatabaseConfigProvider","t":"DatabaseConfigProvider","d":"play.api.db.slick","k":"trait","x":""},
{"l":"play/api/db/slick/DatabaseConfigProvider.html#get-a04","e":false,"i":"","n":"get","t":"get[P <: BasicProfile]: DatabaseConfig[P]","d":"play.api.db.slick.DatabaseConfigProvider","k":"def","x":""},
{"l":"play/api/db/slick/DatabaseConfigProvider$.html#","e":false,"i":"","n":"DatabaseConfigProvider","t":"DatabaseConfigProvider","d":"play.api.db.slick","k":"object","x":""},
{"l":"play/api/db/slick/DatabaseConfigProvider$.html#get-9a6","e":false,"i":"","n":"get","t":"get[P <: BasicProfile](implicit app: Application): DatabaseConfig[P]","d":"play.api.db.slick.DatabaseConfigProvider","k":"def","x":""},
{"l":"play/api/db/slick/DatabaseConfigProvider$.html#get-fffff54b","e":false,"i":"","n":"get","t":"get[P <: BasicProfile](dbName: String)(implicit app: Application): DatabaseConfig[P]","d":"play.api.db.slick.DatabaseConfigProvider","k":"def","x":""},
{"l":"play/api/db/slick/DbName.html#","e":false,"i":"","n":"DbName","t":"DbName(value: String) extends AnyVal","d":"play.api.db.slick","k":"class","x":""},
{"l":"play/api/db/slick/DefaultSlickApi.html#","e":false,"i":"","n":"DefaultSlickApi","t":"DefaultSlickApi(environment: Environment, configuration: Configuration, lifecycle: ApplicationLifecycle)(implicit executionContext: ExecutionContext) extends SlickApi","d":"play.api.db.slick","k":"class","x":""},
{"l":"play/api/db/slick/DefaultSlickApi.html#dbConfig-fffffa29","e":false,"i":"","n":"dbConfig","t":"dbConfig[P <: BasicProfile](name: DbName): DatabaseConfig[P]","d":"play.api.db.slick.DefaultSlickApi","k":"def","x":""},
{"l":"play/api/db/slick/DefaultSlickApi.html#dbConfigs-fffffe9c","e":false,"i":"","n":"dbConfigs","t":"dbConfigs[P <: BasicProfile](): Seq[(DbName, DatabaseConfig[P])]","d":"play.api.db.slick.DefaultSlickApi","k":"def","x":""},
{"l":"play/api/db/slick/DefaultSlickApi$.html#","e":false,"i":"","n":"DefaultSlickApi","t":"DefaultSlickApi","d":"play.api.db.slick","k":"object","x":""},
{"l":"play/api/db/slick/HasDatabaseConfig.html#","e":false,"i":"","n":"HasDatabaseConfig","t":"HasDatabaseConfig[P <: BasicProfile]","d":"play.api.db.slick","k":"trait","x":""},
{"l":"play/api/db/slick/HasDatabaseConfig.html#db-0","e":false,"i":"","n":"db","t":"db: dbConfig.profile.backend.Database","d":"play.api.db.slick.HasDatabaseConfig","k":"def","x":""},
{"l":"play/api/db/slick/HasDatabaseConfig.html#dbConfig-0","e":false,"i":"","n":"dbConfig","t":"dbConfig: DatabaseConfig[P]","d":"play.api.db.slick.HasDatabaseConfig","k":"val","x":""},
{"l":"play/api/db/slick/HasDatabaseConfig.html#driver-0","e":false,"i":"","n":"driver","t":"driver: P","d":"play.api.db.slick.HasDatabaseConfig","k":"val","x":""},
{"l":"play/api/db/slick/HasDatabaseConfig.html#profile-0","e":false,"i":"","n":"profile","t":"profile: P","d":"play.api.db.slick.HasDatabaseConfig","k":"val","x":""},
{"l":"play/api/db/slick/HasDatabaseConfigProvider.html#","e":false,"i":"","n":"HasDatabaseConfigProvider","t":"HasDatabaseConfigProvider[P <: BasicProfile] extends HasDatabaseConfig[P]","d":"play.api.db.slick","k":"trait","x":""},
{"l":"play/api/db/slick/HasDatabaseConfigProvider.html#dbConfig-0","e":false,"i":"","n":"dbConfig","t":"dbConfig: DatabaseConfig[P]","d":"play.api.db.slick.HasDatabaseConfigProvider","k":"val","x":""},
{"l":"play/api/db/slick/HasDatabaseConfigProvider.html#dbConfigProvider-0","e":false,"i":"","n":"dbConfigProvider","t":"dbConfigProvider: DatabaseConfigProvider","d":"play.api.db.slick.HasDatabaseConfigProvider","k":"val","x":""},
{"l":"play/api/db/slick/NamedDatabaseConfigProvider.html#","e":false,"i":"","n":"NamedDatabaseConfigProvider","t":"NamedDatabaseConfigProvider(name: String) extends Provider[DatabaseConfigProvider]","d":"play.api.db.slick","k":"class","x":""},
{"l":"play/api/db/slick/NamedDatabaseConfigProvider.html#get-0","e":false,"i":"","n":"get","t":"get: DatabaseConfigProvider","d":"play.api.db.slick.NamedDatabaseConfigProvider","k":"val","x":""},
{"l":"play/api/db/slick/SlickApi.html#","e":false,"i":"","n":"SlickApi","t":"SlickApi","d":"play.api.db.slick","k":"trait","x":""},
{"l":"play/api/db/slick/SlickApi.html#dbConfig-fffffa29","e":false,"i":"","n":"dbConfig","t":"dbConfig[P <: BasicProfile](name: DbName): DatabaseConfig[P]","d":"play.api.db.slick.SlickApi","k":"def","x":""},
{"l":"play/api/db/slick/SlickApi.html#dbConfigs-fffffe9c","e":false,"i":"","n":"dbConfigs","t":"dbConfigs[P <: BasicProfile](): Seq[(DbName, DatabaseConfig[P])]","d":"play.api.db.slick.SlickApi","k":"def","x":""},
{"l":"play/api/db/slick/SlickComponents.html#","e":false,"i":"","n":"SlickComponents","t":"SlickComponents","d":"play.api.db.slick","k":"trait","x":""},
{"l":"play/api/db/slick/SlickComponents.html#applicationLifecycle-0","e":false,"i":"","n":"applicationLifecycle","t":"applicationLifecycle: ApplicationLifecycle","d":"play.api.db.slick.SlickComponents","k":"def","x":""},
{"l":"play/api/db/slick/SlickComponents.html#configuration-0","e":false,"i":"","n":"configuration","t":"configuration: Configuration","d":"play.api.db.slick.SlickComponents","k":"def","x":""},
{"l":"play/api/db/slick/SlickComponents.html#environment-0","e":false,"i":"","n":"environment","t":"environment: Environment","d":"play.api.db.slick.SlickComponents","k":"def","x":""},
{"l":"play/api/db/slick/SlickComponents.html#executionContext-0","e":false,"i":"","n":"executionContext","t":"executionContext: ExecutionContext","d":"play.api.db.slick.SlickComponents","k":"def","x":""},
{"l":"play/api/db/slick/SlickComponents.html#slickApi-0","e":false,"i":"","n":"slickApi","t":"slickApi: SlickApi","d":"play.api.db.slick.SlickComponents","k":"val","x":""},
{"l":"play/api/db/slick/SlickModule$.html#","e":false,"i":"","n":"SlickModule","t":"SlickModule","d":"play.api.db.slick","k":"object","x":""},
{"l":"play/api/db/slick/SlickModule$.html#DbKeyConfig-0","e":false,"i":"","n":"DbKeyConfig","t":"DbKeyConfig: \"play.slick.db.config\"","d":"play.api.db.slick.SlickModule","k":"val","x":""},
{"l":"play/api/db/slick/SlickModule$.html#DefaultDbName-0","e":false,"i":"","n":"DefaultDbName","t":"DefaultDbName: \"play.slick.db.default\"","d":"play.api.db.slick.SlickModule","k":"val","x":""},
{"l":"play/api/db/slick/SlickModule.html#","e":false,"i":"","n":"SlickModule","t":"SlickModule extends Module","d":"play.api.db.slick","k":"class","x":""},
{"l":"play/api/db/slick/SlickModule.html#bindNamed-a4e","e":false,"i":"","n":"bindNamed","t":"bindNamed(name: String): BindingKey[DatabaseConfigProvider]","d":"play.api.db.slick.SlickModule","k":"def","x":""},
{"l":"play/api/db/slick/SlickModule.html#bindings-4d8","e":false,"i":"","n":"bindings","t":"bindings(environment: Environment, configuration: Configuration): Seq[Binding[_]]","d":"play.api.db.slick.SlickModule","k":"def","x":""},
{"l":"play/api/db/slick/SlickModule.html#defaultDatabaseConfigBinding-8be","e":false,"i":"","n":"defaultDatabaseConfigBinding","t":"defaultDatabaseConfigBinding(default: String, dbs: Set[String]): Seq[Binding[_]]","d":"play.api.db.slick.SlickModule","k":"def","x":""},
{"l":"play/api/db/slick/SlickModule.html#namedDatabaseConfigBindings-fd9","e":false,"i":"","n":"namedDatabaseConfigBindings","t":"namedDatabaseConfigBindings(dbs: Set[String]): Seq[Binding[_]]","d":"play.api.db.slick.SlickModule","k":"def","x":""}];
